@@ -1,6 +1,7 @@
 package Eixo::Base::Clase;
 
 use Eixo::Base::Util;
+use Clone 'clone';
 
 use Attribute::Handlers;
 use strict;
@@ -11,13 +12,27 @@ use parent qw(Exporter);
 our @EXPORT = qw(has);
 
 sub import{
-	no strict "refs";
-	
+	my ($class, $parent) = @_;
+
+	if(my $f = $parent){
+		
+		$f =~ s{::|'}{/}g;
+            	
+		require "$f.pm";
+	}
+
+	$parent = $parent || 'Eixo::Base::Clase';
+
 	my $caller = caller;
+
+	{
+
+		no strict 'refs';
+
+		push @{$caller . '::ISA'}, $parent;
 	
-	push @{$caller . '::ISA'}, "Eixo::Base::Clase";
-	
-	*{$caller . '::has'} = \&has;
+		*{$caller . '::has'} = \&has;
+	};
 }
 
 
@@ -30,37 +45,48 @@ sub has{
 	no strict 'refs';
 	
 	foreach my $attribute (keys(%attributes)){
-			
-		unless(defined(&{$class . '::' . $attribute})){
 
-			*{$class . '::' . $attribute} = sub {
-
-				my ($self, $value)  = @_;
-
-				if(defined($value)){
-					
-					$self->{$attribute} = $value;
-					
-					$self;
-				}
-				else{
-					$self->{$attribute};
-				}	
-
-			};
-		}
+		$class->__createSetterGetter($attribute, $attributes{$attribute});		
 	}
 
 	*{$class . '::' . '__initialize'} = sub {
 
+		my $c_attributes = clone(\%attributes);
+
 		my ($self) = @_;
 
-		foreach(keys %attributes){
-			$self->{$_} = $attributes{$_};
+		foreach(keys %$c_attributes){
+			$self->{$_} = $c_attributes->{$_};
 		}
 	};  
 }
 
+sub __createSetterGetter{
+	my ($class, $attribute, $value) = @_;
+
+	no strict 'refs';
+
+	unless(defined(&{$class . '::' . $attribute})){
+
+		*{$class . '::' . $attribute} = sub {
+
+			my ($self, $value)  = @_;
+
+			if(defined($value)){
+				
+				$self->{$attribute} = $value;
+				
+				$self;
+			}
+			else{
+				$self->{$attribute};
+			}	
+
+		};
+	}
+
+}
+
 sub new{
 	my ($clase, @args) = @_;
 
@@ -69,7 +95,7 @@ sub new{
 	# 3 initilization forms with defined precedence
 
 	# initialize attributes with default values from 'has' hash
-	$self->__initialize;
+	$self->__initialize if($self->can('__initialize'));
 
 	# if new is called with initialization values (not recommended)
 	if(@args % 2 == 0){
